@@ -7,7 +7,7 @@
  */
 
 /*
- * Copyright (C) 2006-2023 Oracle and/or its affiliates.
+ * Copyright (C) 2006-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -433,6 +433,7 @@ static DECLCALLBACK(void) intnetR3RecvAvail(INTNETIFHANDLE hIf, void *pvUser)
         /* Send an empty message. */
         xpc_object_t hObjPoke = xpc_dictionary_create(NULL, NULL, 0);
         xpc_connection_send_message(pSession->hXpcCon, hObjPoke);
+        xpc_release(hObjPoke);
     }
     else
         ASMAtomicXchgBool(&pSession->fRecvAvail, true);
@@ -507,6 +508,7 @@ static void intnetR3RequestProcess(xpc_connection_t hCon, xpc_object_t hObj, PSU
 
                     xpc_dictionary_set_uint64(hObjReply, "rc", INTNET_R3_SVC_SET_RC(rc));
                     xpc_connection_send_message(hCon, hObjReply);
+                    xpc_release(hObjReply);
                     return;
                 }
                 else
@@ -569,6 +571,7 @@ static void intnetR3RequestProcess(xpc_connection_t hCon, xpc_object_t hObj, PSU
                         /* Send an empty message. */
                         xpc_object_t hObjPoke = xpc_dictionary_create(NULL, NULL, 0);
                         xpc_connection_send_message(pSession->hXpcCon, hObjPoke);
+                        xpc_release(hObjPoke);
                     }
                     return;
                 }
@@ -586,6 +589,7 @@ static void intnetR3RequestProcess(xpc_connection_t hCon, xpc_object_t hObj, PSU
                         /* Send an empty message. */
                         xpc_object_t hObjPoke = xpc_dictionary_create(NULL, NULL, 0);
                         xpc_connection_send_message(pSession->hXpcCon, hObjPoke);
+                        xpc_release(hObjPoke);
                     }
                     cbReply = sizeof(INTNETIFABORTWAITREQ);
                 }
@@ -602,10 +606,11 @@ static void intnetR3RequestProcess(xpc_connection_t hCon, xpc_object_t hObj, PSU
     xpc_dictionary_set_uint64(hObjReply, "rc", INTNET_R3_SVC_SET_RC(rc));
     xpc_dictionary_set_data(hObjReply, "reply", &ReqReply, cbReply);
     xpc_connection_send_message(hCon, hObjReply);
+    xpc_release(hObjReply);
 }
 
 
-DECLCALLBACK(void) xpcConnHandler(xpc_connection_t hXpcCon)
+static DECLCALLBACK(void) xpcConnHandler(xpc_connection_t hXpcCon)
 {
     xpc_connection_set_event_handler(hXpcCon, ^(xpc_object_t hObj) {
         PSUPDRVSESSION pSession = (PSUPDRVSESSION)xpc_connection_get_context(hXpcCon);
